pub enum CompassPoint {
N,
NE,
E,
SE,
S,
SW,
W,
NW,
C,
None,
}Variants
N
NE
E
SE
S
SW
W
NW
C
pecifies the center of the node or port
None
specifies that an appropriate side of the port adjacent to the exterior of the node should be used, if such exists.