pub enum RankDir {
TopBottom,
LeftRight,
BottomTop,
RightLeft,
}Expand description
Corresponding to directed graphs drawn from top to bottom, from left to right, from bottom to top, and from right to left, respectively.
Variants